@@ -9,7 +9,7 @@
 #' @importFrom cli style_bold style_underline col_cyan col_yellow col_magenta
 #' @export
 msg_logical <- function() {
-  sprintf(fmt = 'Some scientists do not understand %s value (e.g., %s being %s/%s)\nConsider using 2-level %s (e.g., %s being %s/%s)',
+  sprintf(fmt = '\nSome scientists do not understand %s value (e.g., %s being %s/%s)\nConsider using 2-level %s (e.g., %s being %s/%s)',
           'logical' |> style_underline() |> style_bold(),
           'arm_intervention' |> col_cyan() |> style_bold(),
           'TRUE' |> col_yellow(), 'FALSE' |> col_yellow(),
@@ -18,3 +18,5 @@ msg_logical <- function() {
           'intervention' |> col_yellow(), 'control' |> col_yellow())
 }
 
+# add a `\n` upfront to make sure the error message starts on a new line
+
